-- Author: Luigi Grimaudo
-- E-mail: luigi.grimaudo@polito.it
-- Date: 10/03/2013

-- Data source
set escape on;

drop role acquistiDB_role;
create role acquistiDB_role;

grant create session,connect,create table to acquistiDB_role;

drop user acquistiDB cascade;

CREATE TABLESPACE pentaho_tablespace logging datafile 'pentaho_ts.dbf' size 32m autoextend ON NEXT 32m maxsize 2048m extent management local;

create user acquistiDB identified by "password" default tablespace pentaho_tablespace quota unlimited on pentaho_tablespace temporary tablespace temp quota 5M on system;

grant acquistiDB_role to acquistiDB;
grant create table to acquistiDB;
grant create procedure, create trigger, create sequence, create any table to acquistiDB;

conn acquistiDB/password@xe

-- Create tables
CREATE TABLE FORNITORI
(
	ID int NOT NULL,
	NOME varchar2(100) NOT NULL,
	CITTA varchar2(100) NOT NULL,
	PROVINCIA char(2) NOT NULL,
	LIVELLO int NOT NULL,
	PRIMARY KEY (ID)
);

INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(1,'T1','TORINO','TO',4);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(2,'T2','TORINO','TO',5);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(3,'T3','TORINO','TO',8);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(4,'T4','TORINO','TO',2);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(5,'M1','MONCALIERI','TO',7);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(6,'M2','MONCALIERI','TO',7);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(7,'TR1','TROFARELLO','TO',2);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(8,'TR2','TROFARELLO','TO',3);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(9,'CO1','COLLEGNO','TO',5);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(10,'RI1','RIVOLI','TO',5);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(11,'RI2','RIVOLI','TO',7);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(12,'C1','CUNEO','CN',9);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(13,'C2','CUNEO','CN',7);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(14,'A1','ALBA','CN',5);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(15,'B1','BRA','CN',3);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(16,'B2','ASTI','AT',2);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(17,'VE1','VERCELLI','VC',4);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(18,'VE2','VERCELLI','VC',5);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(19,'CE3','CUNEO','CN',7);
INSERT INTO FORNITORI (ID,nome,citta,provincia,livello) values(20,'T5','TORINO','TO',9);


CREATE TABLE OGGETTI
(
	ID int NOT NULL,
	TIPO varchar2(100) NOT NULL,
	COLORE varchar2(100) NOT NULL,
	PESO number NOT NULL,
	PRIMARY KEY (ID)
);

INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(1,'TIPO1','GIALLO',10.2);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(2,'TIPO2','GIALLO',10.5);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(3,'TIPO3','GIALLO',34.2);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(4,'TIPO4','BLU',5.3);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(5,'TIPO1','BLU',7.0);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(6,'TIPO3','VERDE',3.6);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(7,'TIPO2','VERDE',3.8);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(8,'TIPO4','VERDE',4.8);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(9,'TIPO1','NERO',7.4);
INSERT INTO OGGETTI (ID,TIPO,COLORE,PESO) values(10,'TIPO2','NERO',7.6);

CREATE TABLE TEMPO
(
	ID int NOT NULL,
	DATA date NOT NULL,
	MESE varchar2(100) NOT NULL,
	ANNO int NOT NULL,
	PRIMARY KEY (ID)
);

INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(1,to_date('2008/03/10','yyyy/mm/dd'),'MARZO',2008);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(2,to_date('2008/03/11','yyyy/mm/dd'),'MARZO',2008);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(3,to_date('2008/03/13','yyyy/mm/dd'),'MARZO',2008);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(4,to_date('2008/04/14','yyyy/mm/dd'),'APRILE',2008);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(5,to_date('2009/03/10','yyyy/mm/dd'),'MARZO',2009);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(6,to_date('2009/03/11','yyyy/mm/dd'),'MARZO',2009);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(7,to_date('2009/03/12','yyyy/mm/dd'),'MARZO',2009);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(8,to_date('2009/03/13','yyyy/mm/dd'),'MARZO',2009);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(9,to_date('2009/04/10','yyyy/mm/dd'),'APRILE',2009);
INSERT INTO TEMPO (ID,DATA,MESE,ANNO) values(10,to_date('2009/04/11','yyyy/mm/dd'),'APRILE',2009);

CREATE TABLE ACQUISTI
(
	ID_FORNITORE int NOT NULL,
	ID_OGGETTO int NOT NULL,
	ID_TEMPO int NOT NULL,
	QUANTITA int NOT NULL,
	PRIMARY KEY (ID_FORNITORE, ID_OGGETTO, ID_TEMPO),
	FOREIGN KEY (ID_FORNITORE) REFERENCES FORNITORI (ID),
	FOREIGN KEY (ID_OGGETTO) REFERENCES OGGETTI (ID),
	FOREIGN KEY (ID_TEMPO) REFERENCES TEMPO (ID)
);

INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,1,79);



INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,2,64);


INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,3,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,4,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,5,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,6,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,7,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,8,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,9,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,1,10,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,1,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,2,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,3,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,4,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,5,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,6,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,7,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,8,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,9,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,2,10,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,1,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,2,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,3,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,4,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,5,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,6,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,7,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,8,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,9,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,3,10,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,1,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,2,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,3,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,4,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,5,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,6,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,7,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,8,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,9,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,4,10,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,1,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,2,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,3,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,4,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,5,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,6,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,7,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,8,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,9,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,5,10,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,1,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,2,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,3,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,4,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,5,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,6,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,7,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,8,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,9,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,6,10,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,1,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,2,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,3,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,4,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,5,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,6,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,7,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,8,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,9,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,7,10,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,1,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,2,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,3,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,4,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,5,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,6,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,7,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,8,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,9,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,8,10,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,1,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,2,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,3,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,4,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,5,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,6,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,7,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,8,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,9,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,9,10,12);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,1,19);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,2,13);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,3,58);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,4,7);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,5,82);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,6,59);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,7,63);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,8,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,9,69);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(1,10,10,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,1,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,2,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,3,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,4,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,5,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,6,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,7,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,8,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,9,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,1,10,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,1,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,2,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,3,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,4,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,5,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,6,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,7,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,8,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,9,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,2,10,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,1,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,2,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,3,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,4,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,5,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,6,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,7,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,8,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,9,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,3,10,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,1,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,2,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,3,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,4,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,5,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,6,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,7,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,8,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,9,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,4,10,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,1,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,2,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,3,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,4,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,5,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,6,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,7,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,8,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,9,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,5,10,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,1,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,2,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,3,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,4,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,5,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,6,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,7,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,8,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,9,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,6,10,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,1,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,2,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,3,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,4,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,5,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,6,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,7,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,8,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,9,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,7,10,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,1,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,2,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,3,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,4,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,5,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,6,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,7,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,8,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,9,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,8,10,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,1,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,2,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,3,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,4,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,5,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,6,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,7,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,8,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,9,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,9,10,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,1,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,2,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,3,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,4,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,5,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,6,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,7,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,8,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,9,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(2,10,10,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,1,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,2,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,3,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,4,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,5,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,6,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,7,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,8,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,9,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,1,10,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,1,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,2,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,3,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,4,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,5,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,6,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,7,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,8,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,9,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,2,10,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,1,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,2,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,3,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,4,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,5,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,6,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,7,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,8,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,9,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,3,10,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,1,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,2,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,3,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,4,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,5,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,6,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,7,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,8,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,9,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,4,10,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,1,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,2,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,3,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,4,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,5,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,6,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,7,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,8,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,9,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,5,10,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,1,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,2,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,3,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,4,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,5,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,6,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,7,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,8,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,9,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,6,10,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,1,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,2,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,3,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,4,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,5,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,6,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,7,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,8,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,9,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,7,10,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,1,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,2,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,3,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,4,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,5,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,6,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,7,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,8,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,9,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,8,10,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,1,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,2,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,3,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,4,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,5,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,6,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,7,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,8,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,9,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,9,10,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,1,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,2,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,3,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,4,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,5,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,6,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,7,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,8,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,9,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(3,10,10,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,1,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,2,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,3,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,4,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,5,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,6,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,7,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,8,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,9,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,1,10,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,1,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,2,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,3,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,4,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,5,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,6,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,7,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,8,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,9,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,2,10,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,1,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,2,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,3,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,4,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,5,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,6,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,7,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,8,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,9,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,3,10,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,1,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,2,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,3,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,4,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,5,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,6,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,7,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,8,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,9,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,4,10,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,1,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,2,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,3,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,4,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,5,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,6,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,7,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,8,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,9,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,5,10,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,1,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,2,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,3,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,4,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,5,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,6,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,7,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,8,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,9,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,6,10,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,1,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,2,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,3,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,4,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,5,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,6,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,7,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,8,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,9,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,7,10,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,1,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,2,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,3,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,4,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,5,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,6,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,7,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,8,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,9,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,8,10,61);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,1,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,2,0);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,3,61);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,4,64);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,5,1);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,6,37);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,7,76);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,8,30);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,9,93);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,9,10,30);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,1,67);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,2,1);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,3,10);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,4,40);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,5,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,6,35);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,7,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,8,5);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,9,13);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(4,10,10,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,1,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,2,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,3,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,4,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,5,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,6,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,7,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,8,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,9,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,1,10,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,1,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,2,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,3,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,4,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,5,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,6,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,7,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,8,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,9,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,2,10,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,1,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,2,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,3,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,4,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,5,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,6,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,7,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,8,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,9,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,3,10,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,1,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,2,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,3,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,4,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,5,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,6,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,7,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,8,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,9,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,4,10,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,1,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,2,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,3,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,4,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,5,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,6,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,7,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,8,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,9,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,5,10,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,1,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,2,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,3,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,4,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,5,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,6,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,7,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,8,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,9,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,6,10,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,1,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,2,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,3,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,4,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,5,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,6,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,7,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,8,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,9,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,7,10,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,1,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,2,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,3,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,4,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,5,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,6,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,7,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,8,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,9,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,8,10,44);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,1,61);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,2,37);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,3,58);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,4,67);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,5,77);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,6,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,7,96);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,8,32);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,9,25);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,9,10,17);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,1,31);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,2,54);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,3,10);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,4,66);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,5,70);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,6,26);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,7,57);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,8,11);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,9,48);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(5,10,10,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,1,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,2,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,3,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,4,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,5,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,6,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,7,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,8,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,9,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,1,10,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,1,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,2,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,3,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,4,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,5,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,6,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,7,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,8,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,9,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,2,10,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,1,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,2,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,3,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,4,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,5,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,6,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,7,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,8,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,9,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,3,10,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,1,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,2,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,3,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,4,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,5,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,6,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,7,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,8,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,9,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,4,10,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,1,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,2,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,3,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,4,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,5,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,6,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,7,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,8,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,9,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,5,10,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,1,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,2,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,3,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,4,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,5,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,6,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,7,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,8,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,9,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,6,10,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,1,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,2,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,3,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,4,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,5,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,6,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,7,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,8,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,9,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,7,10,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,1,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,2,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,3,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,4,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,5,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,6,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,7,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,8,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,9,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,8,10,82);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,1,70);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,2,66);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,3,97);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,4,21);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,5,18);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,6,86);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,7,64);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,8,25);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,9,23);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,9,10,7);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,1,28);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,2,79);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,3,40);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,4,82);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,5,77);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,6,31);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,7,73);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,8,96);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,9,37);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(6,10,10,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,1,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,2,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,3,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,4,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,5,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,6,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,7,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,8,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,9,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,1,10,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,1,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,2,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,3,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,4,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,5,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,6,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,7,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,8,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,9,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,2,10,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,1,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,2,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,3,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,4,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,5,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,6,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,7,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,8,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,9,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,3,10,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,1,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,2,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,3,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,4,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,5,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,6,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,7,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,8,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,9,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,4,10,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,1,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,2,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,3,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,4,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,5,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,6,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,7,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,8,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,9,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,5,10,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,1,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,2,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,3,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,4,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,5,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,6,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,7,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,8,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,9,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,6,10,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,1,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,2,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,3,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,4,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,5,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,6,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,7,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,8,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,9,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,7,10,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,1,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,2,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,3,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,4,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,5,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,6,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,7,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,8,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,9,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,8,10,59);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,1,27);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,2,31);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,3,29);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,4,15);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,5,17);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,6,81);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,7,10);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,8,33);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,9,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,9,10,78);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,1,14);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,2,11);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,3,21);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,4,39);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,5,74);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,6,15);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,7,81);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,8,28);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,9,38);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(7,10,10,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,1,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,2,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,3,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,4,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,5,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,6,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,7,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,8,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,9,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,1,10,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,1,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,2,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,3,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,4,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,5,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,6,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,7,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,8,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,9,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,2,10,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,1,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,2,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,3,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,4,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,5,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,6,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,7,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,8,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,9,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,3,10,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,1,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,2,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,3,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,4,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,5,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,6,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,7,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,8,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,9,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,4,10,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,1,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,2,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,3,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,4,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,5,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,6,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,7,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,8,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,9,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,5,10,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,1,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,2,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,3,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,4,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,5,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,6,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,7,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,8,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,9,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,6,10,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,1,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,2,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,3,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,4,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,5,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,6,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,7,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,8,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,9,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,7,10,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,1,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,2,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,3,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,4,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,5,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,6,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,7,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,8,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,9,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,8,10,64);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,1,67);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,2,27);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,3,75);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,4,50);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,5,29);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,6,69);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,7,11);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,8,89);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,9,16);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,9,10,65);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,1,25);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,2,86);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,3,73);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,4,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,5,74);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,6,75);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,7,91);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,8,17);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,9,95);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(8,10,10,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,1,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,2,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,3,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,4,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,5,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,6,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,7,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,8,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,9,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,1,10,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,1,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,2,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,3,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,4,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,5,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,6,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,7,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,8,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,9,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,2,10,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,1,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,2,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,3,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,4,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,5,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,6,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,7,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,8,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,9,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,3,10,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,1,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,2,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,3,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,4,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,5,80);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,6,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,7,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,8,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,9,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,4,10,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,1,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,2,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,3,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,4,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,5,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,6,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,7,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,8,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,9,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,5,10,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,1,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,2,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,3,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,4,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,5,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,6,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,7,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,8,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,9,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,6,10,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,1,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,2,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,3,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,4,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,5,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,6,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,7,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,8,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,9,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,7,10,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,1,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,2,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,3,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,4,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,5,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,6,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,7,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,8,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,9,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,8,10,10);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,1,99);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,2,37);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,3,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,4,94);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,5,62);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,6,27);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,7,29);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,8,64);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,9,87);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,9,10,12);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,1,14);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,2,34);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,3,12);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,4,39);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,5,69);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,6,59);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,7,93);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,8,34);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,9,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(9,10,10,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,1,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,2,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,3,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,4,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,5,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,6,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,7,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,8,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,9,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,1,10,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,1,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,2,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,3,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,4,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,5,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,6,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,7,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,8,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,9,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,2,10,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,1,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,2,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,3,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,4,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,5,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,6,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,7,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,8,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,9,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,3,10,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,1,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,2,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,3,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,4,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,5,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,6,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,7,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,8,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,9,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,4,10,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,1,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,2,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,3,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,4,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,5,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,6,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,7,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,8,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,9,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,5,10,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,1,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,2,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,3,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,4,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,5,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,6,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,7,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,8,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,9,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,6,10,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,1,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,2,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,3,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,4,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,5,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,6,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,7,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,8,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,9,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,7,10,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,1,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,2,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,3,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,4,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,5,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,6,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,7,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,8,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,9,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,8,10,43);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,1,75);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,2,52);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,3,75);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,4,75);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,5,58);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,6,49);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,7,83);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,8,6);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,9,80);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,9,10,44);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,1,22);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,2,49);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,3,74);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,4,54);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,5,96);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,6,75);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,7,59);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,8,73);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,9,71);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(10,10,10,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,1,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,2,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,3,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,4,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,5,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,6,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,7,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,8,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,9,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,1,10,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,1,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,2,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,3,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,4,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,5,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,6,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,7,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,8,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,9,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,2,10,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,1,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,2,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,3,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,4,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,5,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,6,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,7,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,8,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,9,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,3,10,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,1,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,2,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,3,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,4,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,5,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,6,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,7,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,8,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,9,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,4,10,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,1,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,2,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,3,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,4,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,5,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,6,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,7,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,8,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,9,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,5,10,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,1,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,2,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,3,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,4,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,5,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,6,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,7,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,8,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,9,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,6,10,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,1,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,2,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,3,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,4,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,5,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,6,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,7,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,8,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,9,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,7,10,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,1,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,2,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,3,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,4,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,5,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,6,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,7,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,8,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,9,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,8,10,92);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,1,25);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,2,25);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,3,20);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,4,29);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,5,79);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,6,19);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,7,97);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,8,10);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,9,41);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,9,10,48);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,1,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,2,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,3,81);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,4,80);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,5,94);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,6,29);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,7,23);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,8,74);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,9,40);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(11,10,10,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,1,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,2,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,3,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,4,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,5,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,6,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,7,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,8,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,9,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,1,10,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,1,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,2,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,3,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,4,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,5,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,6,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,7,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,8,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,9,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,2,10,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,1,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,2,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,3,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,4,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,5,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,6,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,7,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,8,70);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,9,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,3,10,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,1,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,2,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,3,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,4,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,5,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,6,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,7,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,8,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,9,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,4,10,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,1,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,2,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,3,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,4,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,5,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,6,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,7,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,8,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,9,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,5,10,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,1,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,2,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,3,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,4,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,5,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,6,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,7,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,8,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,9,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,6,10,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,1,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,2,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,3,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,4,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,5,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,6,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,7,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,8,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,9,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,7,10,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,1,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,2,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,3,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,4,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,5,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,6,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,7,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,8,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,9,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,8,10,81);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,1,40);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,2,51);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,3,41);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,4,24);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,5,49);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,6,34);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,7,28);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,8,43);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,9,81);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,9,10,81);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,1,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,2,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,3,48);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,4,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,5,40);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,6,5);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,7,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,8,54);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,9,95);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(12,10,10,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,1,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,2,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,3,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,4,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,5,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,6,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,7,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,8,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,9,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,1,10,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,1,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,2,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,3,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,4,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,5,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,6,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,7,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,8,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,9,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,2,10,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,1,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,2,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,3,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,4,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,5,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,6,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,7,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,8,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,9,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,3,10,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,1,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,2,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,3,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,4,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,5,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,6,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,7,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,8,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,9,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,4,10,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,1,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,2,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,3,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,4,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,5,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,6,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,7,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,8,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,9,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,5,10,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,1,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,2,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,3,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,4,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,5,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,6,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,7,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,8,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,9,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,6,10,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,1,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,2,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,3,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,4,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,5,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,6,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,7,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,8,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,9,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,7,10,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,1,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,2,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,3,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,4,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,5,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,6,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,7,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,8,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,9,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,8,10,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,1,22);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,2,25);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,3,15);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,4,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,5,59);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,6,45);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,7,78);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,8,12);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,9,39);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,9,10,73);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,1,97);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,2,0);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,3,33);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,4,36);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,5,7);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,6,69);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,7,30);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,8,55);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,9,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(13,10,10,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,1,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,2,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,3,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,4,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,5,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,6,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,7,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,8,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,9,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,1,10,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,1,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,2,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,3,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,4,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,5,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,6,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,7,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,8,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,9,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,2,10,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,1,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,2,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,3,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,4,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,5,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,6,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,7,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,8,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,9,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,3,10,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,1,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,2,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,3,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,4,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,5,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,6,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,7,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,8,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,9,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,4,10,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,1,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,2,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,3,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,4,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,5,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,6,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,7,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,8,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,9,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,5,10,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,1,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,2,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,3,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,4,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,5,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,6,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,7,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,8,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,9,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,6,10,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,1,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,2,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,3,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,4,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,5,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,6,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,7,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,8,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,9,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,7,10,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,1,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,2,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,3,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,4,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,5,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,6,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,7,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,8,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,9,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,8,10,11);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,1,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,2,69);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,3,58);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,4,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,5,99);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,6,72);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,7,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,8,94);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,9,21);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,9,10,69);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,1,12);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,2,97);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,3,64);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,4,73);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,5,24);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,6,71);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,7,84);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,8,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,9,99);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(14,10,10,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,1,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,2,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,3,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,4,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,5,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,6,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,7,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,8,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,9,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,1,10,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,1,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,2,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,3,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,4,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,5,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,6,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,7,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,8,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,9,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,2,10,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,1,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,2,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,3,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,4,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,5,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,6,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,7,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,8,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,9,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,3,10,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,1,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,2,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,3,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,4,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,5,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,6,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,7,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,8,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,9,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,4,10,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,1,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,2,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,3,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,4,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,5,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,6,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,7,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,8,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,9,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,5,10,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,1,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,2,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,3,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,4,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,5,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,6,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,7,53);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,8,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,9,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,6,10,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,1,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,2,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,3,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,4,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,5,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,6,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,7,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,8,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,9,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,7,10,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,1,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,2,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,3,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,4,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,5,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,6,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,7,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,8,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,9,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,8,10,73);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,1,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,2,66);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,3,61);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,4,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,5,59);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,6,90);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,7,91);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,8,83);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,9,80);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,9,10,84);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,1,32);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,2,90);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,3,92);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,4,9);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,5,33);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,6,49);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,7,42);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,8,4);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,9,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(15,10,10,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,1,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,2,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,3,99);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,4,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,5,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,6,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,7,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,8,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,9,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,1,10,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,1,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,2,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,3,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,4,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,5,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,6,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,7,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,8,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,9,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,2,10,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,1,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,2,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,3,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,4,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,5,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,6,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,7,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,8,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,9,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,3,10,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,1,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,2,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,3,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,4,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,5,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,6,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,7,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,8,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,9,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,4,10,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,1,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,2,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,3,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,4,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,5,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,6,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,7,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,8,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,9,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,5,10,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,1,57);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,2,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,3,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,4,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,5,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,6,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,7,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,8,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,9,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,6,10,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,1,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,2,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,3,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,4,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,5,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,6,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,7,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,8,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,9,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,7,10,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,1,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,2,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,3,63);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,4,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,5,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,6,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,7,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,8,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,9,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,8,10,65);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,1,89);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,2,13);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,3,35);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,4,66);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,5,51);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,6,70);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,7,38);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,8,89);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,9,34);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,9,10,11);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,1,50);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,2,34);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,3,45);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,4,29);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,5,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,6,48);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,7,72);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,8,53);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,9,8);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(16,10,10,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,1,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,2,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,3,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,4,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,5,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,6,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,7,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,8,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,9,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,1,10,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,1,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,2,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,3,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,4,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,5,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,6,79);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,7,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,8,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,9,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,2,10,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,1,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,2,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,3,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,4,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,5,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,6,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,7,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,8,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,9,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,3,10,50);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,1,14);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,2,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,3,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,4,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,5,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,6,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,7,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,8,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,9,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,4,10,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,1,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,2,18);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,3,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,4,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,5,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,6,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,7,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,8,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,9,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,5,10,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,1,28);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,2,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,3,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,4,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,5,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,6,43);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,7,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,8,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,9,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,6,10,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,1,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,2,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,3,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,4,34);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,5,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,6,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,7,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,8,94);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,9,31);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,7,10,58);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,1,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,2,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,3,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,4,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,5,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,6,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,7,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,8,46);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,9,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,8,10,42);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,1,25);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,2,76);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,3,63);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,4,84);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,5,37);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,6,32);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,7,50);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,8,45);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,9,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,9,10,15);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,1,41);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,2,96);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,3,29);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,4,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,5,57);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,6,82);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,7,63);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,8,88);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,9,58);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(17,10,10,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,1,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,2,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,3,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,4,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,5,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,6,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,7,42);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,8,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,9,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,1,10,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,1,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,2,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,3,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,4,64);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,5,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,6,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,7,86);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,8,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,9,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,2,10,61);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,1,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,2,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,3,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,4,29);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,5,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,6,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,7,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,8,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,9,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,3,10,62);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,1,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,2,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,3,25);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,4,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,5,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,6,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,7,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,8,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,9,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,4,10,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,1,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,2,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,3,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,4,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,5,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,6,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,7,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,8,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,9,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,5,10,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,1,38);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,2,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,3,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,4,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,5,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,6,74);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,7,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,8,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,9,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,6,10,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,1,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,2,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,3,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,4,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,5,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,6,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,7,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,8,66);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,9,23);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,7,10,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,1,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,2,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,3,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,4,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,5,39);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,6,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,7,24);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,8,77);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,9,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,8,10,4);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,1,82);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,2,6);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,3,53);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,4,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,5,8);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,6,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,7,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,8,55);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,9,79);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,9,10,18);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,1,90);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,2,42);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,3,38);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,4,36);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,5,19);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,6,83);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,7,54);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,8,14);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,9,21);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(18,10,10,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,1,83);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,2,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,3,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,4,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,5,81);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,6,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,7,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,8,0);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,9,47);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,1,10,35);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,1,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,2,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,3,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,4,59);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,5,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,6,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,7,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,8,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,9,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,2,10,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,1,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,2,44);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,3,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,4,95);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,5,21);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,6,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,7,22);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,8,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,9,48);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,3,10,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,1,16);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,2,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,3,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,4,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,5,98);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,6,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,7,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,8,27);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,9,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,4,10,68);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,1,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,2,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,3,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,4,85);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,5,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,6,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,7,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,8,88);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,9,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,5,10,56);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,1,49);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,2,76);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,3,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,4,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,5,87);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,6,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,7,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,8,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,9,84);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,6,10,54);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,1,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,2,45);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,3,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,4,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,5,13);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,6,33);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,7,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,8,93);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,9,26);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,7,10,96);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,1,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,2,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,3,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,4,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,5,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,6,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,7,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,8,10);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,9,82);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,8,10,56);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,1,52);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,2,44);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,3,21);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,4,53);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,5,30);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,6,23);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,7,63);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,8,85);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,9,2);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,9,10,12);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,1,15);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,2,76);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,3,26);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,4,84);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,5,91);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,6,73);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,7,60);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,8,51);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,9,55);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(19,10,10,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,1,20);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,2,92);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,3,41);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,4,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,5,72);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,6,60);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,7,51);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,8,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,9,17);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,1,10,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,1,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,2,69);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,3,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,4,36);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,5,91);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,6,71);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,7,12);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,8,11);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,9,97);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,2,10,32);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,1,19);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,2,55);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,3,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,4,100);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,5,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,6,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,7,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,8,73);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,9,37);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,3,10,30);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,1,67);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,2,90);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,3,89);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,4,52);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,5,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,6,15);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,7,78);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,8,65);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,9,75);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,4,10,40);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,1,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,2,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,3,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,4,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,5,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,6,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,7,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,8,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,9,9);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,5,10,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,1,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,2,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,3,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,4,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,5,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,6,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,7,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,8,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,9,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,6,10,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,1,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,2,8);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,3,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,4,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,5,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,6,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,7,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,8,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,9,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,7,10,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,1,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,2,1);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,3,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,4,7);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,5,4);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,6,2);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,7,6);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,8,3);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,9,5);
INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,8,10,9);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,1,11);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,2,49);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,3,79);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,4,98);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,5,76);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,6,72);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,7,41);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,8,68);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,9,66);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,9,10,92);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,1,22);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,2,54);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,3,94);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,4,7);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,5,82);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,6,47);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,7,32);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,8,38);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,9,64);
--INSERT INTO ACQUISTI (ID_FORNITORE,ID_OGGETTO,ID_TEMPO,QUANTITA) values(20,10,10,48);

commit;
exit;